@@ -70,4 +70,6 @@ pub enum Error {
     TokenError(String),
     #[error("{0}")]
     ApiError(ApiError),
+    #[error("Unknown error: {0}")]
+    UnknownError(String),
 }
