@@ -25,6 +25,6 @@ pub(crate) struct LoginResponse {
 
 #[derive(Debug, Clone, Deserialize)]
 pub(crate) struct LoginInnerResponse {
-    pub(crate) reason: ApiError,
+    pub(crate) reason: Option<ApiError>,
     pub(crate) result: String,
 }
